@@ -924,6 +924,8 @@ void SessionImpl::SetEnvironmentVariables()
 
   // Ghostscript
   Utils::SetEnvironmentString("GSC", MIKTEX_GS_EXE);
+#endif
+
   vector<string> gsDirectories;
   PathName gsDir = GetSpecialPath(SpecialPath::CommonInstallRoot) / "ghostscript" / "base";
   if (Directory::Exists(gsDir))
@@ -952,7 +954,34 @@ void SessionImpl::SetEnvironmentVariables()
     }
   }
   MIKTEX_ASSERT(!gsDirectories.Empty());
+
+#if defined(MIKTEX_WINDOWS)
   Utils::SetEnvironmentString("MIKTEX_GS_LIB", StringUtil::Flatten(gsDirectories, PathName::PathNameDelimiter));
+#else
+  string origGsLib;
+  if (Utils::GetEnvironmentString("GS_LIB", origGsLib))
+  {
+    vector<string> origGsLibDirectories = StringUtil::Split(origGsLib, PathName::PathNameDelimiter);
+    vector<string> toBeAdded;
+    for (const string& d1 : origGsLibDirectories)
+    {
+      bool duplicate = false;
+      for (const string& d2 : gsDirectories)
+      {
+        if (PathName::Compare(d1, d2) == 0)
+        {
+          duplicate = true;
+          break;
+        }
+      }
+      if (!duplicate)
+      {
+        toBeAdded.push_back(d1);
+      }
+    }
+    gsDirectories.insert(gsDirectories.end(), toBeAdded.begin(), toBeAdded.end());
+  }
+  Utils::SetEnvironmentString("GS_LIB", StringUtil::Flatten(gsDirectories, PathName::PathNameDelimiter));
 #endif
 
   PathName path = GetTempDirectory();
