@@ -1,6 +1,6 @@
 /* PackageDataStore.cpp
 
-   Copyright (C) 2018 Christian Schenk
+   Copyright (C) 2018-2019 Christian Schenk
 
    This file is part of MiKTeX Package Manager.
 
@@ -101,15 +101,7 @@ tuple<bool, PackageInfo> PackageDataStore::TryGetPackage(const string& packageId
 
 void PackageDataStore::SetTimeInstalled(const string& packageId, time_t timeInstalled)
 {
-  (*this)[packageId].timeInstalled = timeInstalled;
-  if (session->IsAdminMode())
-  {
-    (*this)[packageId].timeInstalledByAdmin = timeInstalled;
-  }
-  else
-  {
-    (*this)[packageId].timeInstalledByUser = timeInstalled;
-  }
+  (*this)[packageId].SetTimeInstalled(timeInstalled, session->IsAdminMode() ? ConfigurationScope::Common : ConfigurationScope::User);
   if (IsValidTimeT(timeInstalled))
   {
     comboCfg.PutValue(packageId, "TimeInstalled", std::to_string(timeInstalled));
@@ -152,17 +144,15 @@ void PackageDataStore::DefinePackage(const PackageInfo& packageInfo)
     // installed from the start
     p.first->second.isRemovable = false;
     p.first->second.isObsolete = false;
-    p.first->second.timeInstalled = packageInfo.timePackaged;
-    p.first->second.timeInstalledByAdmin = packageInfo.timePackaged;
-    p.first->second.timeInstalledByUser = packageInfo.timePackaged;
+    p.first->second.timeInstalledCommon = packageInfo.timePackaged;
+    p.first->second.timeInstalledUser = packageInfo.timePackaged;
   }
   else
   {
     p.first->second.isRemovable = IsRemovable(p.first->second.id);
     p.first->second.isObsolete = IsObsolete(p.first->second.id);
-    p.first->second.timeInstalled = GetTimeInstalled(p.first->second.id);
-    p.first->second.timeInstalledByAdmin = GetCommonTimeInstalled(p.first->second.id);
-    p.first->second.timeInstalledByUser = GetUserTimeInstalled(p.first->second.id);
+    p.first->second.timeInstalledCommon = GetTimeInstalled(p.first->second.id, ConfigurationScope::Common);
+    p.first->second.timeInstalledUser = GetTimeInstalled(p.first->second.id, ConfigurationScope::User);
     if (p.first->second.IsInstalled())
     {
       p.first->second.releaseState = GetReleaseState(p.first->second.id);
@@ -317,21 +307,28 @@ void PackageDataStore::Load(Cfg& cfg)
       else
       {
         it3->second.requiredBy.push_back(pkg.id);
-        if (it3->second.timeInstalled < timeInstalledMin)
+        if (it3->second.GetTimeInstalled() < timeInstalledMin)
         {
-          timeInstalledMin = it3->second.timeInstalled;
+          timeInstalledMin = it3->second.GetTimeInstalled();
         }
-        if (it3->second.timeInstalled > timeInstalledMax)
+        if (it3->second.GetTimeInstalled() > timeInstalledMax)
         {
-          timeInstalledMax = it3->second.timeInstalled;
+          timeInstalledMax = it3->second.GetTimeInstalled();
         }
       }
     }
     if (timeInstalledMin > 0)
     {
-      if (pkg.IsPureContainer() || (pkg.IsInstalled() && pkg.timeInstalled < timeInstalledMax))
+      if (pkg.IsPureContainer() || (pkg.IsInstalled() && pkg.GetTimeInstalled() < timeInstalledMax))
       {
-        pkg.timeInstalled = timeInstalledMax;
+        if (session->IsAdminMode())
+        {
+          pkg.timeInstalledCommon = timeInstalledMax;
+        }
+        else
+        {
+          pkg.timeInstalledUser = timeInstalledMax;
+        }
       }
     }
   }
@@ -399,25 +396,11 @@ PackageInfo& PackageDataStore::operator[](const string& packageId)
   return it->second;
 }
 
-time_t PackageDataStore::GetUserTimeInstalled(const string& packageId)
+time_t PackageDataStore::GetTimeInstalled(const string& packageId, ConfigurationScope scope)
 {
   LoadVarData();
   string str;
-  if (comboCfg.TryGetValueAsString(ComboCfg::Scope::User, packageId, "TimeInstalled", str))
-  {
-    return Utils::ToTimeT(str);
-  }
-  else
-  {
-    return InvalidTimeT;
-  }
-}
-
-time_t PackageDataStore::GetCommonTimeInstalled(const std::string& packageId)
-{
-  LoadVarData();
-  string str;
-  if (comboCfg.TryGetValueAsString(ComboCfg::Scope::Common, packageId, "TimeInstalled", str))
+  if (comboCfg.TryGetValueAsString(scope, packageId, "TimeInstalled", str))
   {
     return Utils::ToTimeT(str);
   }
@@ -431,8 +414,8 @@ time_t PackageDataStore::GetTimeInstalled(const string& packageId)
 {
   LoadVarData();
   string str;
-  if ((!session->IsAdminMode() && comboCfg.TryGetValueAsString(ComboCfg::Scope::User, packageId, "TimeInstalled", str))
-    || comboCfg.TryGetValueAsString(ComboCfg::Scope::Common, packageId, "TimeInstalled", str))
+  if ((!session->IsAdminMode() && comboCfg.TryGetValueAsString(ConfigurationScope::User, packageId, "TimeInstalled", str))
+    || comboCfg.TryGetValueAsString(ConfigurationScope::Common, packageId, "TimeInstalled", str))
   {
     return Utils::ToTimeT(str);
   }
@@ -450,7 +433,7 @@ bool PackageDataStore::IsRemovable(const string& packageId)
   if (session->IsAdminMode())
   {
     // administrator can remove system-wide packages
-    ret = IsValidTimeT(GetCommonTimeInstalled(packageId));
+    ret = IsValidTimeT(GetTimeInstalled(packageId, ConfigurationScope::Common));
   }
   else
   {
@@ -461,7 +444,7 @@ bool PackageDataStore::IsRemovable(const string& packageId)
     }
     else
     {
-      ret = IsValidTimeT(GetUserTimeInstalled(packageId));
+      ret = IsValidTimeT(GetTimeInstalled(packageId, ConfigurationScope::User));
     }
   }
   return ret;
@@ -471,8 +454,8 @@ bool PackageDataStore::IsObsolete(const string& packageId)
 {
   LoadVarData();
   string str;
-  if ((!session->IsAdminMode() && comboCfg.TryGetValueAsString(ComboCfg::Scope::User, packageId, "Obsolete", str))
-    || comboCfg.TryGetValueAsString(ComboCfg::Scope::Common, packageId, "Obsolete", str))
+  if ((!session->IsAdminMode() && comboCfg.TryGetValueAsString(ConfigurationScope::User, packageId, "Obsolete", str))
+    || comboCfg.TryGetValueAsString(ConfigurationScope::Common, packageId, "Obsolete", str))
   {
     return std::stoi(str) != 0;
   }
@@ -517,5 +500,5 @@ void PackageDataStore::IncrementFileRefCounts(const vector<string>& files)
 size_t PackageDataStore::GetNumberOfInstalledPackages(bool userScope)
 {
   LoadVarData();
-  return comboCfg.GetSize(userScope ? ComboCfg::Scope::User : ComboCfg::Scope::Common);
+  return comboCfg.GetSize(userScope ? ConfigurationScope::User : ConfigurationScope::Common);
 }
