@@ -278,7 +278,7 @@ bool WebAppInputLine::AllowFileName(const PathName& fileName, bool forInput)
   return Utils::IsSafeFileName(fileName);
 }
 
-bool WebAppInputLine::OpenOutputFile(C4P::FileRoot& f, const PathName& fileName, bool text, PathName& outPath)
+bool WebAppInputLine::OpenOutputFile(C4P::FileRoot& f, const PathName& fileName, bool isTextFile_deprecated, PathName& outPath)
 {
   const char* lpszPath = fileName.GetData();
 #if defined(MIKTEX_WINDOWS)
@@ -353,7 +353,7 @@ bool WebAppInputLine::OpenOutputFile(C4P::FileRoot& f, const PathName& fileName,
       path = pimpl->outputDirectory / lpszPath;
       lpszPath = path.GetData();
     }
-    file = session->TryOpenFile(lpszPath, FileMode::Create, FileAccess::Write, text);
+    file = session->TryOpenFile(lpszPath, FileMode::Create, FileAccess::Write, false);
     if (file != nullptr)
     {
       outPath = lpszPath;
@@ -533,7 +533,7 @@ bool WebAppInputLine::OpenInputFile(C4P::FileRoot& f, const PathName& fileName)
 
   f.Attach(pFile, true);
 
-#ifdef PASCAL_TEXT_IO
+#if defined(PASCAL_TEXT_IO)
   not_implemented();
   get(f);
 #endif
@@ -683,11 +683,6 @@ bool WebAppInputLine::InputLine(C4P_text& f, C4P_boolean bypassEndOfLine) const
   MIKTEX_UNEXPECTED();
 #endif
 
-  if (feof(f) != 0)
-  {
-    return false;
-  }
-
   IInputOutput* inputOutput = GetInputOutput();
 
   const C4P_signed32 first = inputOutput->first();
@@ -717,6 +712,11 @@ bool WebAppInputLine::InputLine(C4P_text& f, C4P_boolean bypassEndOfLine) const
 
   last = first;
 
+  if (feof(f) != 0)
+  {
+    return false;
+  }
+
   int ch = GetCharacter(f);
   if (ch == EOF)
   {
