@@ -50,12 +50,29 @@ extern void fix_o_mode(void);
 #  include "lualib.h"
 #ifdef LuajitTeX
 #  include "luajit.h"
+#endif
+
+/* Names */
+#ifndef LUATEX_HARFBUZZ_ENABLED
+#ifdef LuajitTeX
 #  define MyName "LuajitTeX"
 #  define my_name "luajittex"
 #else
 #  define MyName "LuaTeX"
 #  define my_name "luatex"
 #endif
+#endif
+
+#ifdef LUATEX_HARFBUZZ_ENABLED
+#ifdef LuajitTeX
+#  define MyName "LuajitHBTeX"
+#  define my_name "luajithbtex"
+#else
+#  define MyName "LuaHBTeX"
+#  define my_name "luahbtex"
+#endif
+#endif
+
 
 #ifdef __cplusplus
 extern "C" {
@@ -94,6 +111,10 @@ extern int luaopen_sha2(lua_State * L);
  extern int luaopen_ffi(lua_State * L);
 #endif
 
+#ifdef LUATEX_HARFBUZZ_ENABLED
+extern int luaopen_luaharfbuzz(lua_State * L);
+#endif
+
 extern int luaopen_zlib(lua_State * L);
 extern int luaopen_gzip(lua_State * L);
 extern int luaopen_ff(lua_State * L);
@@ -778,6 +799,7 @@ make_lua_key(hlist);\
 make_lua_key(hmode_par);\
 make_lua_key(hmove);\
 make_lua_key(hold_head);\
+make_lua_key(horizontal);\
 make_lua_key(horiz_variants);\
 make_lua_key(hrule);\
 make_lua_key(hsize);\
@@ -1117,6 +1139,7 @@ make_lua_key(stretch_order);\
 make_lua_key(string);\
 make_lua_key(style);\
 make_lua_key(sub);\
+make_lua_key(subfont);\
 make_lua_key(sub_box);\
 make_lua_key(sub_mark);\
 make_lua_key(sub_mlist);\
@@ -1194,6 +1217,7 @@ make_lua_key(variable);\
 make_lua_key(vbox);\
 make_lua_key(vcenter);\
 make_lua_key(version);\
+make_lua_key(vertical);\
 make_lua_key(vert_italic);\
 make_lua_key(vert_variants);\
 make_lua_key(visiblefilename);\
@@ -1481,6 +1505,7 @@ init_lua_key(hlist);\
 init_lua_key(hmode_par);\
 init_lua_key(hmove);\
 init_lua_key(hold_head);\
+init_lua_key(horizontal);\
 init_lua_key(horiz_variants);\
 init_lua_key(hrule);\
 init_lua_key(hsize);\
@@ -1808,6 +1833,7 @@ init_lua_key(stretch_order);\
 init_lua_key(string);\
 init_lua_key(style);\
 init_lua_key(sub);\
+init_lua_key(subfont);\
 init_lua_key(sub_box);\
 init_lua_key(sub_mark);\
 init_lua_key(sub_mlist);\
@@ -1884,6 +1910,7 @@ init_lua_key(variable);\
 init_lua_key(vbox);\
 init_lua_key(vcenter);\
 init_lua_key(version);\
+init_lua_key(vertical);\
 init_lua_key(vert_italic);\
 init_lua_key(vert_variants);\
 init_lua_key(visiblefilename);\
@@ -2235,6 +2262,7 @@ use_lua_key(hlist);
 use_lua_key(hmode_par);
 use_lua_key(hmove);
 use_lua_key(hold_head);
+use_lua_key(horizontal);
 use_lua_key(horiz_variants);
 use_lua_key(hrule);
 use_lua_key(hsize);
@@ -2574,6 +2602,7 @@ use_lua_key(stretch_order);
 use_lua_key(string);
 use_lua_key(style);
 use_lua_key(sub);
+use_lua_key(subfont);
 use_lua_key(sub_box);
 use_lua_key(sub_mark);
 use_lua_key(sub_mlist);
@@ -2651,6 +2680,7 @@ use_lua_key(variable);
 use_lua_key(vbox);
 use_lua_key(vcenter);
 use_lua_key(version);
+use_lua_key(vertical);
 use_lua_key(vert_italic);
 use_lua_key(vert_variants);
 use_lua_key(visiblefilename);
